@@ -19,5 +19,5 @@ rm *.sh LICENSE || exit 1
 cd "$cwd" || exit 1
 
 mkdir -p "$PREFIX/bin" || exit 1
-cp "${RECIPE_DIR}/.mathjax-post-link.sh" "$PREFIX/bin/" || exit 1
-cp "${RECIPE_DIR}/.mathjax-pre-unlink.sh" "$PREFIX/bin/" || exit 1
+cp "${RECIPE_DIR}/mathjax-path" "$PREFIX/bin/" || exit 1
+chmod +x "$PREFIX/bin/mathjax-path" || exit 1
